@@ -1,14 +1,12 @@
 package Data::FormValidator::Constraints::Business::DK::Phonenumber;
 
-# $Id$
-
 use strict;
 use warnings;
 use vars qw($VERSION @EXPORT_OK);
 use Business::DK::Phonenumber qw(validate render);
 use base qw(Exporter);
 
-$VERSION   = '0.08';
+$VERSION   = '0.09';
 @EXPORT_OK = qw(valid_dk_phonenumber match_dk_phonenumber);
 
 use constant VALID   => 1;
@@ -52,7 +50,7 @@ Data::FormValidator::Constraints::Business::DK::Phonenumber - a DFV constraints
 
 =head1 VERSION
 
-This documentation describes version 0.01
+This documentation describes version 0.09
 
 =head1 SYNOPSIS
 
@@ -176,15 +174,10 @@ Jonas B. Nielsen, (jonasbn) - C<< <jonasbn@cpan.org> >>
 
 =head1 COPYRIGHT
 
-Data-FormValidator-Business-DK-Phonenumber is (C) by Jonas B. Nielsen, (jonasbn)
-2008-2009
+Business-DK-Phonenumber and related is (C) by Jonas B. Nielsen, (jonasbn) 2008-2014
 
 =head1 LICENSE
 
-Data-FormValidator-Business-DK-Phonenumber is released under the artistic license
-
-The distribution is licensed under the Artistic License, as specified
-by the Artistic file in the standard perl distribution
-(http://www.perl.com/language/misc/Artistic.html).
+Business-DK-Phonenumber and related is released under the Artistic License 2.0
 
 =cut
